@@ -31,7 +31,7 @@ let LOW_PRIORITY_GET = 2;
 
 class Cmd4PriorityPollingQueue
 {
-   constructor( log, queueName, queueType = constants.DEFAULT_QUEUE_TYPE )
+   constructor( log, queueName, queueType = constants.DEFAULT_QUEUE_TYPE, queueRetryCount = constants.DEFAULT_WORM_QUEUE_RETRY_COUNT )
    {
       this.log = log;
 
@@ -40,6 +40,7 @@ class Cmd4PriorityPollingQueue
 
       this.queueName = queueName;
       this.queueType = queueType;
+      this.queueRetryCount = queueRetryCount;
       this.queueStarted = false;
       this.highPriorityQueue = [ ];
       this.lowPriorityQueue = [ ];
@@ -64,73 +65,121 @@ class Cmd4PriorityPollingQueue
       // The WoRm queue needs error messages to be silenced as
       // they are inevitable, but are handled through retries
       // By default non WoRm queues are allowed to echo errors
-      this.echoE = true;
+
+      if ( this.queueRetryCount == 0 || settings.debug )
+         this.echoE = true;
+      else
+         this.echoE = true;
 
       this.changeQueueType( this, queueType );
    }
 
-   prioritySetValue( accTypeEnumIndex, characteristicString, timeout, stateChangeResponseTime,  value, callback )
+   echoRetryErrors( currentRetryCount )
    {
-      let self = this;
+      // If debug then the default is true
+      if ( settings.cmd4Debug )
+         return true;
+
+      // Since this is the last retry, echo the error
+      if ( currentRetryCount == this.queueRetryCount )
+         return true;
+
+      return false;
+   }
+
+   // This function is called by homebridge to *PUT AN ENTRY INTO THE HIGHEST PRIORITY SET QUEUE*.
+   // We immediately return success if the device is accessible. Either way the Set is attempted
+   // above everything else except other SetValue requests.
+   prioritySetValue( accTypeEnumIndex, characteristicString, timeout, stateChangeResponseTime,  value, homebridgeCallback )
+   {
+      // this is Accessory
+      //
+      //if ( settings.cmd4Dbg ) this.log.debug(`prioritySetValue, asked to set: ${ characteristicString } to ${ value }`);
 
       // Save the value to cache. The set will come later
-      self.cmd4Storage.setStoredValueForIndex( accTypeEnumIndex, value );
-      callback( 0 );
+      // this.cmd4Storage.setStoredValueForIndex( accTypeEnumIndex, value );
 
-      let newEntry = { [ constants.IS_SET_lv ]: true, [ constants.ACCESSORY_lv ]: self, [ constants.ACC_TYPE_ENUM_INDEX_lv ]: accTypeEnumIndex, [ constants.CHARACTERISTIC_STRING_lv ]: characteristicString, [ constants.TIMEOUT_lv ]: timeout, [ constants.STATE_CHANGE_RESPONSE_TIME_lv ]: stateChangeResponseTime, [ constants.CALLBACK_lv ]: callback, [ constants.VALUE_lv ]: value };
+      if ( this.errorValue != 0 )
+      {
+         if ( settings.cmd4Dbg ) this.log.debug(`prioritySetValue for ${ this.displayName }, homebridgeCallback returning error ${ this.errorValue } ${ this.errorString }`);
+         homebridgeCallback( this.errorValue );
+      } else
+      {
+         if ( settings.cmd4Dbg ) this.log.debug(`prioritySetValue for ${ this.displayName }, homebridgeCallback returning default success 0`);
+         homebridgeCallback( 0 );
+      }
+
+      let newEntry = { [ constants.IS_SET_lv ]: true, [ constants.ACCESSORY_lv ]: this, [ constants.ACC_TYPE_ENUM_INDEX_lv ]: accTypeEnumIndex, [ constants.CHARACTERISTIC_STRING_lv ]: characteristicString, [ constants.TIMEOUT_lv ]: timeout, [ constants.STATE_CHANGE_RESPONSE_TIME_lv ]: stateChangeResponseTime, [ constants.CALLBACK_lv ]: homebridgeCallback, [ constants.VALUE_lv ]: value };
 
       // Determine where to put the entry in the queue
-      if ( self.queue.highPriorityQueue.length == 0 )
+      if ( this.queue.highPriorityQueue.length == 0 )
       {
          // No entries, then it goes on top
-         self.queue.highPriorityQueue.push( newEntry );
+         this.queue.highPriorityQueue.push( newEntry );
 
       } else {
 
          // Make sure that this is the latest "Set" of this entry
-         let index = self.queue.highPriorityQueue.findIndex( ( entry ) => entry.accessory.uuid == self.uuid && entry.isSet == true && entry.accTypeEnumIndex == accTypeEnumIndex );
+         let index = this.queue.highPriorityQueue.findIndex( ( entry ) => entry.accessory.uuid == this.uuid && entry.isSet == true && entry.accTypeEnumIndex == accTypeEnumIndex );
 
          if ( index == -1 )
          {
             // It doesn't exist in the queue, It needs to be placed after any "Sets".
             // First Determine the first "Get"
-            let getIndex = self.queue.highPriorityQueue.findIndex( ( entry ) => entry.isSet == false );
+            let getIndex = this.queue.highPriorityQueue.findIndex( ( entry ) => entry.isSet == false );
 
             if ( getIndex == -1 )
             {
                // No "Get" entrys, it goes at the end after everything.
-               self.queue.highPriorityQueue.push( newEntry );
+               this.queue.highPriorityQueue.push( newEntry );
 
             } else
             {
                // Insert before the first "Get" entry
-               self.queue.highPriorityQueue.splice( getIndex, 0, newEntry );
+               this.queue.highPriorityQueue.splice( getIndex, 0, newEntry );
             }
          } else
          {
-            self.queue.highPriorityQueue[ index ] = newEntry;
+            this.queue.highPriorityQueue[ index ] = newEntry;
          }
       }
-      self.queue.processQueueFunc( HIGH_PRIORITY_SET, self.queue );
+      this.queue.processQueueFunc( HIGH_PRIORITY_SET, this.queue );
    }
 
-   priorityGetValue( accTypeEnumIndex, characteristicString, timeout, callback )
+   // This function is called by homebridge to *PUT AN ENTRY INTO THE HIGHEST PRIORITY GET QUEUE*.
+   // We immediately return with success and the last known value if the device is accessible, otherwise
+   // the last failure error code.
+   // The Get is attempted no matter the devices availability. This is done after every Set
+   // request and at the bottom of the hightPrioritySetValue queue, but above any polling.
+   priorityGetValue( accTypeEnumIndex, characteristicString, timeout, homebridgeCallback )
    {
-      let self = this;
+      // this is Accessory
 
-      // return the cached value
-      let storedValue = self.cmd4Storage.getStoredValueForIndex( accTypeEnumIndex );
-      callback( 0, storedValue );
+      // if ( settings.cmd4Dbg ) this.log.debug(`priorityGetValue for ${ this.displayName }, asked to Get: ${ characteristicString }`);
 
-      if ( self.queue.queueType != constants.QUEUETYPE_WORM2 )
+      if ( this.errorValue != 0 )
+      {
+         // if ( settings.cmd4Dbg ) this.log.debug(`priorityGetValue for ${ this.displayName }, homebridgeCallback returning error ${ this.errorValue } ${ this.errorString}`);
+         homebridgeCallback( this.errorValue );
+      } else
+      {
+         // return the cached value
+         let storedValue = this.cmd4Storage.getStoredValueForIndex( accTypeEnumIndex );
+
+         // if ( settings.cmd4Dbg ) this.log.debug(`priorityGetValue for ${ this.displayName }, homebridgeCallback returning storedValue: ${ storedValue }`);
+         homebridgeCallback( 0, storedValue );
+      }
+
+      if ( this.queue.queueType != constants.QUEUETYPE_WORM2 )
       {
          // When the value is returned, it will update homebridge
-         self.queue.highPriorityQueue.push( { [ constants.IS_SET_lv ]: false, [ constants.QUEUE_GET_IS_UPDATE_lv ]: true, [ constants.ACCESSORY_lv ]: self, [ constants.ACC_TYPE_ENUM_INDEX_lv ]: accTypeEnumIndex, [ constants.CHARACTERISTIC_STRING_lv ]: characteristicString, [ constants.TIMEOUT_lv ]: timeout, [ constants.STATE_CHANGE_RESPONSE_TIME_lv ]: null, [ constants.VALUE_lv ]: null, [ constants.CALLBACK_lv ]: callback } );
+         this.queue.highPriorityQueue.push( { [ constants.IS_SET_lv ]: false, [ constants.QUEUE_GET_IS_UPDATE_lv ]: true, [ constants.ACCESSORY_lv ]: this, [ constants.ACC_TYPE_ENUM_INDEX_lv ]: accTypeEnumIndex, [ constants.CHARACTERISTIC_STRING_lv ]: characteristicString, [ constants.TIMEOUT_lv ]: timeout, [ constants.STATE_CHANGE_RESPONSE_TIME_lv ]: null, [ constants.VALUE_lv ]: null, [ constants.CALLBACK_lv ]: homebridgeCallback } );
 
-         self.queue.processQueueFunc( HIGH_PRIORITY_GET, self.queue );
+         this.queue.processQueueFunc( HIGH_PRIORITY_GET, this.queue );
       }
    }
 
+   // This function is called by polling to *PUT AN ENTRY INTO THE LOW PRIORITY POLLING QUEUE*.
    addLowPriorityGetPolledQueueEntry( accessory, accTypeEnumIndex, characteristicString, interval, timeout )
    {
       // These are all gets from polling
@@ -148,28 +197,34 @@ class Cmd4PriorityPollingQueue
 
          let queue = entry.accessory.queue;
 
+         // Save the error code - Pass or fail
+         entry.accessory.errorValue = error;
+
          if ( error == 0 )
          {
+            // Now that the set was successful, store the value
+            entry.accessory.cmd4Storage.setStoredValueForIndex( entry.accTypeEnumIndex, entry.value );
+
             // Since the "Set" passed, do the stateChangeResponseTime
             setTimeout( ( ) =>
             {
-               // A set with no error means the queue is sane to do reading
-               queue.lastGoodTransactionTime = Date.now( );
-               queue.errorCountSinceLastGoodTransaction = 0;
+            // A set with no error means the queue is sane to do reading
+            queue.lastGoodTransactionTime = Date.now( );
+            queue.errorCountSinceLastGoodTransaction = 0;
 
-               // After the stateChangeResponseTime, do the related characteristic ( if any )
-               let relatedCurrentAccTypeEnumIndex = entry.accessory.getDevicesRelatedCurrentAccTypeEnumIndex( entry.accTypeEnumIndex );
+            // After the stateChangeResponseTime, do the related characteristic ( if any )
+            let relatedCurrentAccTypeEnumIndex = entry.accessory.getDevicesRelatedCurrentAccTypeEnumIndex( entry.accTypeEnumIndex );
 
                if ( relatedCurrentAccTypeEnumIndex != null )
-               {
-                  let relatedCurrentCharacteristicString = CMD4_ACC_TYPE_ENUM.properties[ relatedCurrentAccTypeEnumIndex ].type;
-                  // Change the entry to a get and set queueGetIsUpdate to true
-                  // Use unshift to make it next in line
-                  entry.isSet = false;
-                  entry.accTypeEnumIndex = relatedCurrentAccTypeEnumIndex;
-                  entry.characteristicString = relatedCurrentCharacteristicString;
-                  entry.queueGetIsUpdate = true;
-                  queue.highPriorityQueue.unshift( entry );
+            {
+            let relatedCurrentCharacteristicString = CMD4_ACC_TYPE_ENUM.properties[ relatedCurrentAccTypeEnumIndex ].type;
+            // Change the entry to a get and set queueGetIsUpdate to true
+            // Use unshift to make it next in line
+            entry.isSet = false;
+            entry.accTypeEnumIndex = relatedCurrentAccTypeEnumIndex;
+            entry.characteristicString = relatedCurrentCharacteristicString;
+            entry.queueGetIsUpdate = true;
+            queue.highPriorityQueue.unshift( entry );
                }
 
                // The "Set" is now complete after its stateChangeResponseTime.
@@ -177,24 +232,43 @@ class Cmd4PriorityPollingQueue
 
                setTimeout( ( ) => { queue.processQueueFunc( HIGH_PRIORITY_GET, queue ); }, 0 );
 
-               return;
+            return;
 
             }, entry.stateChangeResponseTime );
 
          } else  // setValue failed
          {
-
             // The "Set" is complete, even if it failed.
             queue.inProgressSets --;
 
-            // Set failed. We need to keep trying
-            queue.highPriorityQueue.push( entry );
+            let currentRetryCount = queue.errorCountSinceLastGoodTransaction;
 
-            queue.errorCountSinceLastGoodTransaction++;
-            let count = queue.errorCountSinceLastGoodTransaction;
+            if ( currentRetryCount >= queue.queueRetryCount )
+            {
+               if ( queue.echoRetryErrors( currentRetryCount ) )
+               {
+                  // Counting starts from zero, i.e queueRetries = 0, so add 1
+                  queue.log.warn( `*${ currentRetryCount + 1 }* error(s) were encountered for "${ entry.accessory.displayName }" getValue. Last error found Getting: "${ entry.characteristicString}". Perhaps you should run in debug mode to find out what the problem might be.` );
+               }
 
-            if ( count != 0 && count % 50 == 0 )
-               queue.log.warn( `More than *${ count }* errors were encountered in a row for "${ entry.accessory.displayName }" setValue. Last error found Setting: "${ entry.characteristicString}". Perhaps you should run in debug mode to find out what the problem might be.` );
+               // Convert the errorValue into an errorString
+               entry.accessory.errorString = new Error( constants.errorString( error ) );
+
+               // This does not work - Nothing happens to HomeKit !
+               // queue.log.warn( `START processHighPrioritySetQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue} errorString: ${ entry.accessory.errorString }`);
+               // entry.accessory.service.getCharacteristic( CMD4_ACC_TYPE_ENUM.properties[ entry.accTypeEnumIndex ].characteristic ).updateValue( entry.accessory.errorString );
+               // queue.log.warn( `END processHighPrioritySetQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue} errorString: ${ entry.accessory.errorString }`);
+
+
+            } else
+            {
+               // Increment the errorCount/currentRetryCount
+               queue.errorCountSinceLastGoodTransaction++;
+
+               // Set failed. We need to keep trying
+               queue.highPriorityQueue.push( entry );
+
+            }
 
             entry.accessory.queue.pauseQueue( entry.accessory.queue );
          }
@@ -204,7 +278,7 @@ class Cmd4PriorityPollingQueue
          // created.
 
          // Note 2.
-         // We cannot release the queue for further processing as the 
+         // We cannot release the queue for further processing as the
          // statechangeResponseTime has not completed. This must be
          // done first or any next "Get" or "Set" would interfere
          // with the device
@@ -222,28 +296,50 @@ class Cmd4PriorityPollingQueue
       {
          let queue = entry.accessory.queue;
 
+         // Save the error code - Pass or fail
+         entry.accessory.errorValue = error;
+
          // Nothing special was done for casing on errors, so omit it.
          if ( error == 0 )
          {
-            if ( entry.queueGetIsUpdate == true )
+            // Save the new returned value
+            entry.accessory.cmd4Storage.setStoredValueForIndex( entry.accTypeEnumIndex, properValue );
+
+            // hmmm if ( entry.queueGetIsUpdate == true )
                entry.accessory.service.getCharacteristic( CMD4_ACC_TYPE_ENUM.properties[ entry.accTypeEnumIndex ].characteristic ).updateValue( properValue );
 
              // A good anything, updates the lastGoodTransactionTime
             queue.lastGoodTransactionTime = Date.now( );
             queue.errorCountSinceLastGoodTransaction = 0;
 
-         } else  // getValue failed
+         } else  // highPriority getValue failed
          {
-            // High Priority Get failed. We need to keep trying (WoRm queue only )
-            if ( queue.queueType == constants.QUEUETYPE_WORM ||
-                 queue.queueType == constants.QUEUETYPE_WORM2
-               )
-               queue.highPriorityQueue.push( entry );
 
-            queue.errorCountSinceLastGoodTransaction++;
-            let count = queue.errorCountSinceLastGoodTransaction;
-            if ( count != 0 && count % 50 == 0 )
-               queue.log.warn( `More than *${ count }* errors were encountered in a row for "${ entry.accessory.displayName }" getValue. Last error found Getting: "${ entry.characteristicString}". Perhaps you should run in debug mode to find out what the problem might be.` );
+            let currentRetryCount = queue.errorCountSinceLastGoodTransaction;
+
+            if ( currentRetryCount >= queue.queueRetryCount )
+            {
+               if ( queue.echoRetryErrors( currentRetryCount ) )
+                  queue.log.warn( `*${ currentRetryCount + 1}* error(s) were encountered for "${ entry.accessory.displayName }" getValue. Last error found Getting: "${ entry.characteristicString}". Perhaps you should run in debug mode to find out what the problem might be.` );
+
+               // Convert the errorValue into an errorString
+               entry.accessory.errorString = new Error( constants.errorString( error ) );
+
+               // This does not work - Nothing happens to HomeKit !
+               // queue.log.warn( `START processHighPriorityGetQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue} errorString: ${ entry.accessory.errorString }`);
+               // entry.accessory.service.getCharacteristic( CMD4_ACC_TYPE_ENUM.properties[ entry.accTypeEnumIndex ].characteristic ).updateValue( entry.accessory.errorString );
+               // queue.log.warn( `END processHighPriorityGetQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue} errorString: ${ entry.accessory.errorString }`);
+
+            } else
+            {
+               // Increment the errorCount/currentRetryCount
+               queue.errorCountSinceLastGoodTransaction++;
+
+               // High Priority Get failed. We keep retrying until the mod of
+               // queueRetryCount reaches zero, which is WoRm only as it has more than 1
+               // default retry count.
+               queue.highPriorityQueue.push( entry );
+            }
 
             entry.accessory.queue.pauseQueue( entry.accessory.queue );
          }
@@ -254,6 +350,7 @@ class Cmd4PriorityPollingQueue
       });
    }
 
+   // This is called from polling
    processEntryFromLowPriorityQueue( entry )
    {
       if ( settings.cmd4Dbg ) this.log.debug( `Processing low priority queue entry: ${ entry.accTypeEnumIndex }` );
@@ -268,20 +365,40 @@ class Cmd4PriorityPollingQueue
          // For the next one
          queue.inProgressGets --;
 
+         // Save the error code - Pass or fail
+         entry.accessory.errorValue = error;
+
          // Nothing special was done for casing on errors, so omit it.
          if ( error == 0 )
          {
+            // Save the new value
+            entry.accessory.cmd4Storage.setStoredValueForIndex( entry.accTypeEnumIndex, properValue );
+
+            if ( settings.cmd4Dbg ) entry.accessory.log.debug( `processEntryFromLowPriorityQueue calling updateValue properValue: ${ properValue }`);
+
+            // Update the new value in homebridge
             entry.accessory.service.getCharacteristic( CMD4_ACC_TYPE_ENUM.properties[ entry.accTypeEnumIndex ].characteristic ).updateValue( properValue );
 
              // A good anything, updates the lastGoodTransactionTime
             queue.lastGoodTransactionTime = Date.now( );
             queue.errorCountSinceLastGoodTransaction = 0;
 
-         } else {
+         } else { // LowPriority getValue failed
+            queue.errorCountSinceLastGoodTransaction++;
+
+            // Convert the errorValue into an errorString
+            entry.accessory.errorString = new Error( constants.errorString( error ));
+
+            // This does not work - Nothing happens to HomeKit !
+            // Call updateValue with new Error so device will become unavailable
+            // queue.log.warn( `START processEntryFromLowPriorityQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue } errorString: ${ entry.accessory.errorString }`);
+            // entry.accessory.service.getCharacteristic( CMD4_ACC_TYPE_ENUM.properties[ entry.accTypeEnumIndex ].characteristic ).updateValue( entry.accessory.errorString );
+            // queue.log.warn( `END processEntryFromLowPriorityQueue calling updateCharacteristic errorValue: ${ entry.accessory.errorValue } errorString: ${ entry.accessory.errorString }`);
+
             queue.pauseQueue( entry.accessory.queue );
          }
 
-         // Now that this one has been processed, schedule it again.
+         // Now that this one has been processed, schedule it again for next time
          queue.scheduleLowPriorityEntry( entry )
 
       });
@@ -477,7 +594,7 @@ class Cmd4PriorityPollingQueue
    //
    //       - Where he value in <> is an one of CMD4_ACC_TYPE_ENUM
    // ***********************************************
-   qSetValue( accessory, accTypeEnumIndex, characteristicString, timeout, value, callback )
+   qSetValue( accessory, accTypeEnumIndex, characteristicString, timeout, value, queueCallback )
    {
       let self = accessory;
       let queue = accessory.queue;
@@ -515,17 +632,17 @@ class Cmd4PriorityPollingQueue
             {
                if ( queue.echoE  ) self.log.error( chalk.red( `setValue ${ characteristicString } function failed for ${ self.displayName } cmd: ${ cmd } Failed.  Error: ${ code } ${ constants.DBUSY }` ) );
 
-               callback( constants.ERROR_TIMER_EXPIRED );
+               queueCallback( constants.ERROR_TIMER_EXPIRED );
 
                return;
             }
 
-            callback( code );
+            queueCallback( code );
 
             return;
          }
 
-         callback( code );
+         queueCallback( code );
 
       });
    }
@@ -537,13 +654,21 @@ class Cmd4PriorityPollingQueue
    {
       // "WoRm", No matter what, only one "Set" allowed
       if ( queue.inProgressSets > 0 )
+      {
+         // if ( settings.cmd4Dbg ) queue.log.debug(`processWormQueue queue.inProgressSets > 0 : ${queue.inProgressSets}`);
+ 
          // We are *NOT* processing the low prioirity queue entry
          return false;
+      }
 
       // It is not a good time to do a anything, so skip it
       if ( queue.lastGoodTransactionTime == 0 )
+      {
+         // if ( settings.cmd4Dbg ) queue.log.debug(`processWormQueue queue.lastGoodTransactionTime == 0`);
+
          // We are *NOT* processing the low prioirity queue entry
          return false;
+      }
 
       if ( queue.highPriorityQueue.length > 0 )
       {
@@ -556,9 +681,13 @@ class Cmd4PriorityPollingQueue
             // cannot be run with an entry already in progress.
             if ( nextEntry.accessory.queue.inProgressSets > 0 ||
                  nextEntry.accessory.queue.inProgressGets > 0 )
+            {
                // Return as queue is busy.
                // Return false as we are *NOT* processing the low prioirity queue entry
+               // if ( settings.cmd4Dbg ) queue.log.debug(`processWormQueue queue.inProgressSets> 0 ${ nextEntry.accessory.queue.inProgressSets } ${ nextEntry.accessory.queue.inProgressGets }`);
+
                return false;
+            }
 
             queue.processHighPrioritySetQueue( queue.highPriorityQueue.shift( ) );
 
@@ -695,38 +824,44 @@ class Cmd4PriorityPollingQueue
       if ( lastTransactionType == LOW_PRIORITY_GET &&
            lowPriorityEntry != null &&
            queue.queueStarted == true )
+      {
          queue.processEntryFromLowPriorityQueue( lowPriorityEntry );
+      }
 
       if ( queue.highPriorityQueue.length > 0 )
       {
          let nextEntry = queue.highPriorityQueue[ 0 ];
 
          if ( nextEntry.isSet == true )
+         {
 
             queue.processHighPrioritySetQueue( queue.highPriorityQueue.shift( ) );
+         }
          else
+         {
             queue.processHighPriorityGetQueue( queue.highPriorityQueue.shift( ) );
+         }
       }
    }
 
    scheduleLowPriorityEntry( entry )
    {
-      let self = entry.accessory;
+      let accessory = entry.accessory;
       let queue = entry.accessory.queue;
 
-      if ( settings.cmd4Dbg ) self.log.debug( `Scheduling Poll of index: ${ entry.accTypeEnumIndex } characteristic: ${ entry.characteristicString } for: ${ self.displayName } timeout: ${ entry.timeout } interval: ${ entry.interval }` );
+      if ( settings.cmd4Dbg ) accessory.log.debug( `Scheduling Poll of index: ${ entry.accTypeEnumIndex } characteristic: ${ entry.characteristicString } for: ${ accessory.displayName } timeout: ${ entry.timeout } interval: ${ entry.interval }` );
 
       // Clear polling
       if ( queue.listOfRunningPolls &&
-           queue.listOfRunningPolls[ self.displayName + entry.accTypeEnumIndex ] == undefined )
-              clearTimeout( queue.listOfRunningPolls[ self.displayName + entry.accTypeEnumIndex ] );
+           queue.listOfRunningPolls[ accessory.displayName + entry.accTypeEnumIndex ] == undefined )
+              clearTimeout( queue.listOfRunningPolls[ accessory.displayName + entry.accTypeEnumIndex ] );
 
-      queue.listOfRunningPolls[ self.displayName + entry.accTypeEnumIndex ] = setTimeout( ( ) =>
+      queue.listOfRunningPolls[ accessory.displayName + entry.accTypeEnumIndex ] = setTimeout( ( ) =>
       {
          // If the queue was busy/not available, schedule the entry at a later time
          if ( queue.processQueueFunc( LOW_PRIORITY_GET, queue, entry ) == false )
          {
-            if ( settings.cmd4Dbg ) self.log.debug( `processsQueue returned false` );
+            if ( settings.cmd4Dbg ) accessory.log.debug( `processsQueue returned false` );
 
             queue.scheduleLowPriorityEntry( entry );
          }
@@ -803,12 +938,17 @@ class Cmd4PriorityPollingQueue
             setTimeout( ( ) =>
             {
                if ( entryIndex == 0 && settings.cmd4Dbg )
+               {
                   if ( queue.queueType == constants.QUEUETYPE_WORM ||
                        queue.queueType == constants.QUEUETYPE_WORM2
                      )
+                  {
                      entry.accessory.log.debug( `Started staggered kick off of ${ queue.lowPriorityQueue.length } polled characteristics for queue: "${ entry.accessory.queue.queueName }"` );
-                  else
+                  } else
+                  {
                      entry.accessory.log.debug( `Started staggered kick off of ${ queue.lowPriorityQueue.length } polled characteristics for "${ entry.accessory.displayName }"` );
+                  }
+               }
 
                if ( settings.cmd4Dbg ) entry.accessory.log.debug( `Kicking off polling for: ${ entry.accessory.displayName } ${ entry.characteristicString } interval:${ entry.interval }, staggered:${ staggeredDelays[ staggeredDelayIndex ] }` );
 
@@ -817,12 +957,18 @@ class Cmd4PriorityPollingQueue
                if ( entryIndex == queue.lowPriorityQueue.length -1 )
                {
                   if ( settings.cmd4Dbg )
+                  {
                      if ( queue.queueType == constants.QUEUETYPE_WORM ||
                           queue.queueType == constants.QUEUETYPE_WORM2
                         )
+                     {
                         entry.accessory.log.debug( `All characteristics are now being polled for queue: "${ queue.queueName }"` );
+                     }
                      else
+                     {
                         entry.accessory.log.debug( `All characteristics are now being polled for "${ entry.accessory.displayName }"` );
+                     }
+                  }
                   allDoneCallback( allDoneCount );
                }
 
@@ -901,15 +1047,15 @@ var queueExists = function( queueName )
    return settings.listOfCreatedPriorityQueues[ queueName ];
 }
 
-var addQueue = function( log, queueName, queueType = constants.DEFAULT_QUEUE_TYPE )
+var addQueue = function( log, queueName, queueType = constants.DEFAULT_QUEUE_TYPE, queueRetryCount = constants.DEFAULT_WORM_QUEUE_RETRY_COUNT )
 {
    let queue = queueExists( queueName );
    if ( queue != undefined )
       return queue;
 
-   log.debug( `Creating new Priority Polled Queue "${ queueName }" with QueueType of: "${ queueType }"` );
+   log.debug( `Creating new Priority Polled Queue "${ queueName }" with QueueType of: "${ queueType }" retryCount: ${queueRetryCount}` );
 
-   queue = new Cmd4PriorityPollingQueue( log, queueName, queueType );
+   queue = new Cmd4PriorityPollingQueue( log, queueName, queueType, queueRetryCount );
    settings.listOfCreatedPriorityQueues[ queueName ] = queue;
 
    return queue;
@@ -927,6 +1073,7 @@ var parseAddQueueTypes = function ( log, entrys )
    {
       let queueName = null;
       let queueType = constants.DEFAULT_QUEUE_TYPE;
+      let queueRetryCount = constants.DEFAULT_WORM_QUEUE_RETRY_COUNT;
 
       for ( let key in entry )
       {
@@ -950,25 +1097,33 @@ var parseAddQueueTypes = function ( log, entrys )
 
                break;
             case constants.QUEUETYPE:
-               if ( value != constants.QUEUETYPE_WORM &&
-                    value != constants.QUEUETYPE_WORM2 &&
-                    value != constants.QUEUETYPE_SEQUENTIAL )
+               // Set the default Queue Retry Count based on QueueType
+               switch ( value )
                {
-                  throw new Error( `QueueType: ${ entry.queueType } is not valid at index: ${ entryIndex }. Expected: ${ constants.QUEUETYPE_WORM }, ${ constants.QUEUETYPE_WORM2 } or ${ constants.QUEUETYPE_SEQUENTIAL }` );
+                  case constants.QUEUETYPE_WORM:
+                     queueRetryCount = constants.DEFAULT_WORM_QUEUE_RETRY_COUNT;
+                     queueType = value;
+                     break;
+                  case constants.QUEUETYPE_WORM2:
+                     queueRetryCount = constants.DEFAULT_WORM_QUEUE_RETRY_COUNT;
+                     queueType = value;
+                     break;
+                  case constants.QUEUETYPE_SEQUENTIAL:
+                     queueRetryCount = constants.DEFAULT_STANDARD_QUEUE_RETRY_COUNT;
+                     queueType = value;
+                     break;
+                  case constants.QUEUETYPE_STANDARD:
+                     queueRetryCount = constants.DEFAULT_STANDARD_QUEUE_RETRY_COUNT;
+                     queueType = value;
+                     break;
+                  default:
+                     throw new Error( `QueueType: ${ entry.queueType } is not valid at index: ${ entryIndex }. Expected: ${ constants.QUEUETYPE_WORM }, ${ constants.QUEUETYPE_WORM2 } or ${ constants.QUEUETYPE_SEQUENTIAL }` );
                }
 
-               queueType = value;
-
                break;
-            case "QueueInterval":
-            case "QueueMsg":
-            case "QueueStatMsgInterval":
-
-               // Never put into production
-               log.warn( `Warning: ${ key } has been deprecated. It was never really used anyway.` );
-               log.warn( `To remove this message, just remove ${ key } from your config.json` );
-
-              break;
+            case constants.QUEUE_RETRIES:
+               queueRetryCount = value;
+               break;
             default:
                throw new Error( `Unknown Queue option"${ key }  not provided at index ${ entryIndex }` );
          }
@@ -978,8 +1133,9 @@ var parseAddQueueTypes = function ( log, entrys )
       if ( queueName == null )
          throw new Error( `"${ constants.QUEUE }"  not provided at index ${ entryIndex }` );
 
-      if ( settings.cmd4Dbg ) log.debug( `calling addQueue: ${ queueName } type: ${ queueType }` );
-      addQueue( log, queueName, queueType );
+      if ( settings.cmd4Dbg ) log.debug( `calling addQueue: ${ queueName } type: ${ queueType } retryCount: ${ queueRetryCount }` );
+
+      addQueue( log, queueName, queueType, queueRetryCount );
    } );
 }
 
